@@ -23,7 +23,7 @@ class TestCase(unittest.TestCase):
 
     def test_html_attributes(self):
         assert str(div(_id='mydiv', _class='test', **{"_aria-label": True}, **{"_data-name": True}, _onclick="alert('hi');")) == \
-            '''<div id="mydiv" class="test" aria-label="True" data-name="True" onclick="alert('hi');"></div>'''
+            '''<div id="mydiv" class="test" aria-label="true" data-name="true" onclick="alert('hi');"></div>'''
 
         myel = div(_id='mydiv', _class='test', **{"_aria-label": True}, **{"_data-name": True}, _onclick="alert('hi');")
         assert myel.id == "mydiv"
@@ -944,6 +944,54 @@ class TestCase(unittest.TestCase):
         print(f"{d}")
 
 
+    def test_four_oh_four(self):
+        # https://github.com/byteface/domonic/issues/37
+        four_oh_four = html(
+            head(
+                meta(_charset="utf-8")
+            ),
+            body(
+                h1("Page Not Found"),
+                p("Sorry, but the page you were trying to view does not exist."),
+            ),
+            _lang="en"
+        )
+        outp = f"{four_oh_four}"
+        # previous incorrect output had a closing meta tag?!. due to no __format__ rule for closed_tags
+        '''
+        <!DOCTYPE html>
+        <html lang="en">
+            <head>
+                <meta charset="utf-8">
+                </meta>
+            </head>
+            <body>
+                <h1>Page Not Found</h1>
+                <p>Sorry, but the page you were trying to view does not exist.</p>
+            </body>
+        </html>
+        '''
+        assert '</meta>' not in outp
+
+
+    def test_boolean_attributes(self):
+        # https://github.com/byteface/domonic/issues/40
+        s = script(_src="foo.js", _async="async")
+        print(s)
+        assert '<script src="foo.js" async></script>' == str(s)
+
+        s = script(_src="foo.js", _async='')
+        print(s)
+        # assert '<script src="foo.js"></script>' == str(s)
+
+        s = script(_src="foo.js", _async='', _hidden='', _checked='')
+        print(s)
+        assert '<script src="foo.js" async hidden checked></script>' == str(s)
+
+        s = script(_src="foo.js", _async=True, _hidden=False, _checked=True)
+        print(s)
+        assert '<script src="foo.js" async="true" hidden="false" checked="true"></script>' == str(s)
+
 
 if __name__ == '__main__':
     unittest.main()
